@@ -81,8 +81,11 @@ preceded with a _
 # Let the code begin...
 
 package Bio::DB::WebDBSeqI;
-$Bio::DB::WebDBSeqI::VERSION = '1.7.4';
+$Bio::DB::WebDBSeqI::VERSION = '1.7.5';
 use strict;
+
+use Carp;
+
 use vars qw($MODVERSION %RETRIEVAL_TYPES $DEFAULT_RETRIEVAL_TYPE
 	    $DEFAULTFORMAT $LAST_INVOCATION_TIME @ATTRIBUTES);
 
@@ -297,7 +300,7 @@ sub get_Stream_by_id {
 
 *get_Stream_by_batch = sub {
   my $self = shift;
-  $self->deprecated('get_Stream_by_batch() is deprecated; use get_Stream_by_id() instead');
+  Carp::carp('get_Stream_by_batch() is deprecated; use get_Stream_by_id() instead');
   $self->get_Stream_by_id(@_)
 };
 
