@@ -102,8 +102,11 @@ methods.
 # Let the code begin...
 
 package Bio::Ontology::Term;
-$Bio::Ontology::Term::VERSION = '1.7.4';
+$Bio::Ontology::Term::VERSION = '1.7.5';
 use strict;
+
+use Carp;
+
 use Bio::Ontology::Ontology;
 use Bio::Ontology::OntologyStore;
 use Bio::Annotation::DBLink;
@@ -428,11 +431,11 @@ sub remove_synonyms {
 
 sub get_dblinks {
     my ($self, $context) = @_;
-    $self->deprecated("Use of get_dblinks is deprecated.  Note that prior use\n".
-                      "of this method could return either simple scalar values\n".
-                      "or Bio::Annotation::DBLink instances; only \n".
-                      "Bio::Annotation::DBLink is now supported.\n ".
-                      "Use get_dbxrefs() instead");
+    Carp::carp("Use of get_dblinks is deprecated.  Note that prior use\n".
+               "of this method could return either simple scalar values\n".
+               "or Bio::Annotation::DBLink instances; only \n".
+               "Bio::Annotation::DBLink is now supported.\n ".
+               "Use get_dbxrefs() instead");
     $self->get_dbxrefs($context);
 } # get_dblinks
 
@@ -479,7 +482,7 @@ sub get_dbxrefs {
 
 sub get_dblink_context {
     my $self=shift;
-    $self->deprecated("Use of get_dblink_context() is deprecated; use get_dbxref_context() instead");
+    Carp::carp("Use of get_dblink_context() is deprecated; use get_dbxref_context() instead");
     return $self->get_dbxref_context(@_);
 }
 
@@ -515,8 +518,8 @@ sub get_dbxref_context {
 
 sub add_dblink {
     my $self = shift;
-    $self->deprecated("Use of simple strings and add_dblink() is deprecated; use\n".
-                      "Bio::Annotation::DBLink instances and add_dbxref() instead");
+    Carp::carp("Use of simple strings and add_dblink() is deprecated; use\n".
+               "Bio::Annotation::DBLink instances and add_dbxref() instead");
     # here we're assuming the data is in a simple DB:ID format
     my @dbxrefs;
     for my $string (@_) {
@@ -581,7 +584,7 @@ sub add_dbxref {
 
 sub has_dblink {
     my ( $self, $value ) = @_;
-    $self->deprecated("use of has_dblink() is deprecated; use has_dbxref() instead");
+    Carp::carp("use of has_dblink() is deprecated; use has_dbxref() instead");
     return $self->has_dbxref($value);
 }
 
@@ -630,8 +633,8 @@ sub has_dbxref {
 
 sub add_dblink_context {
     my ($self, $value, $context) = @_;
-    $self->deprecated("Use of simple strings and add_dblink_context() is deprecated; use\n
-                      Bio::Annotation::DBLink instances and add_dbxref() instead");
+    Carp::carp("Use of simple strings and add_dblink_context() is deprecated; use\n
+               Bio::Annotation::DBLink instances and add_dbxref() instead");
     return $self->add_dbxref([$value],$context);
 }
 
@@ -651,7 +654,7 @@ sub add_dblink_context {
 
 sub remove_dblinks {
     my ($self, $context) = @_;
-    $self->deprecated("use of remove_dblinks() is deprecated; use remove_dbxrefs() instead");
+    Carp::carp("use of remove_dblinks() is deprecated; use remove_dbxrefs() instead");
     return $self->remove_dbxrefs(@_);
 } # remove_dblinks
 
