@@ -1,7 +1,11 @@
 package Bio::Root::Exception;
-$Bio::Root::Exception::VERSION = '1.7.4';
+$Bio::Root::Exception::VERSION = '1.7.5';
 use strict;
 
+=head1 NAME
+
+Bio::Root::Exception - BioPerl exceptions
+
 =head1 SYNOPSIS
 
 =head2 Throwing exceptions using L<Error.pm throw|Error::throw>:
