@@ -1,10 +1,14 @@
 package Bio::Root::Utilities;
-$Bio::Root::Utilities::VERSION = '1.7.4';
+$Bio::Root::Utilities::VERSION = '1.7.5';
 use strict;
 use Bio::Root::IO;
 use Bio::Root::Exception;
 use base qw(Bio::Root::Root Exporter);
 
+=head1 NAME
+
+Bio::Root::Utilities - general-purpose utilities
+
 =head1 SYNOPSIS
 
 =head2 Object Creation
