@@ -106,8 +106,11 @@ methods. Internal methods are usually preceded with a _
 
 
 package Bio::SeqFeature::Primer;
-$Bio::SeqFeature::Primer::VERSION = '1.7.4';
+$Bio::SeqFeature::Primer::VERSION = '1.7.5';
 use strict;
+
+use Carp;
+
 use Bio::PrimarySeq;
 use Bio::Tools::SeqStats;
 
@@ -131,11 +134,8 @@ sub new {
     # Legacy stuff
     my $sequence = delete $args{-sequence};
     if ($sequence) {
-        Bio::Root::Root->deprecated(
-            -message => 'Creating a Bio::SeqFeature::Primer with -sequence is deprecated. Use -seq instead.',
-            -warn_version  => '1.6',
-            -throw_version => '1.8',
-        );
+        Carp::carp("Constructing a Bio::SeqFeature::Primer with -sequence is"
+                   . " deprecated. Use -seq instead.");
         $args{-seq} = $sequence;
     }
 
@@ -155,11 +155,9 @@ sub location {
     if ($location) {
         if ( not ref $location ) {
             # Use location as a string for backward compatibility
-            Bio::Root::Root->deprecated(
-                -message => 'Passing a string to location() is deprecated. Pass a Bio::Location::Simple object or use start() and end() instead.',
-                -warn_version  => '1.6',
-                -throw_version => '1.8',
-            );
+            Carp::carp("Passing a string to location() is deprecated. Pass a"
+                       . " Bio::Location::Simple object or use start() and"
+                       . " end() instead.");
             $self->{'_location'} = $location;
         } else {
             $self->SUPER::location($location);
