@@ -407,8 +407,8 @@ Internal methods are usually preceded with a _
 
 # Let the code begin...
 
-package Bio::Tools::Run::WrapperBase;
-$Bio::Tools::Run::WrapperBase::VERSION = '1.7.4'; # need these methods in WrapperBase/maj
+package Bio::Tools::Run::WrapperBase; # need these methods in WrapperBase/maj
+$Bio::Tools::Run::WrapperBase::VERSION = '1.7.5';
 use strict;
 use warnings;
 no warnings qw(redefine);
@@ -927,7 +927,7 @@ sub _collate_subcmd_args {
 
  Title   : _run
  Usage   : $fac->_run( @file_args )
- Function: Run a command as specified during object contruction
+ Function: Run a command as specified during object construction
  Returns : true on success
  Args    : a specification of the files to operate on according
            to the filespec
