@@ -1,5 +1,5 @@
 package Bio::Tools::SeqPattern::Backtranslate;
-$Bio::Tools::SeqPattern::Backtranslate::VERSION = '1.7.4';
+$Bio::Tools::SeqPattern::Backtranslate::VERSION = '1.7.5';
 use strict;
 use warnings;
 
@@ -8,7 +8,7 @@ use base qw(Exporter);
 
 =head1 NAME
 
-Bio::Tools::SeqPattern::Backtranslate
+Bio::Tools::SeqPattern::Backtranslate - reverse translate protein patterns
 
 =head1 DESCRIPTION
 
