@@ -13,7 +13,7 @@
 
 =head1 NAME
 
-Bio::TreeIO::newick
+Bio::TreeIO::newick - parsing and writing of Newick/PHYLIP/New Hampshire format
 
 =head1 SYNOPSIS
 
@@ -72,7 +72,7 @@ Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::TreeIO::newick;
-$Bio::TreeIO::newick::VERSION = '1.7.4';
+$Bio::TreeIO::newick::VERSION = '1.7.5';
 use strict;
 
 use Bio::Event::EventGeneratorI;
